Class: Aws::Proton::Types::EnvironmentAccountConnectionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-proton/types.rb

Overview

Summary data of an Proton environment account connection resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the environment account connection.

Returns:

  • (String)


2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
# File 'lib/aws-sdk-proton/types.rb', line 2290

class EnvironmentAccountConnectionSummary < Struct.new(
  :arn,
  :component_role_arn,
  :environment_account_id,
  :environment_name,
  :id,
  :last_modified_at,
  :management_account_id,
  :requested_at,
  :role_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#component_role_arn ⇒ String

The Amazon Resource Name (ARN) of the IAM service role that Proton uses when provisioning directly defined components in the associated environment account. It determines the scope of infrastructure that a component can provision in the account.

The environment account connection must have a componentRoleArn to allow directly defined components to be associated with any environments running in the account.

For more information about components, see Proton components in the Proton User Guide.

Returns:

  • (String)


2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
# File 'lib/aws-sdk-proton/types.rb', line 2290

class EnvironmentAccountConnectionSummary < Struct.new(
  :arn,
  :component_role_arn,
  :environment_account_id,
  :environment_name,
  :id,
  :last_modified_at,
  :management_account_id,
  :requested_at,
  :role_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#environment_account_id ⇒ String

The ID of the environment account that's connected to the environment account connection.

Returns:

  • (String)


2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
# File 'lib/aws-sdk-proton/types.rb', line 2290

class EnvironmentAccountConnectionSummary < Struct.new(
  :arn,
  :component_role_arn,
  :environment_account_id,
  :environment_name,
  :id,
  :last_modified_at,
  :management_account_id,
  :requested_at,
  :role_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#environment_name ⇒ String

The name of the environment that's associated with the environment account connection.

Returns:

  • (String)


2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
# File 'lib/aws-sdk-proton/types.rb', line 2290

class EnvironmentAccountConnectionSummary < Struct.new(
  :arn,
  :component_role_arn,
  :environment_account_id,
  :environment_name,
  :id,
  :last_modified_at,
  :management_account_id,
  :requested_at,
  :role_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the environment account connection.

Returns:

  • (String)


2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
# File 'lib/aws-sdk-proton/types.rb', line 2290

class EnvironmentAccountConnectionSummary < Struct.new(
  :arn,
  :component_role_arn,
  :environment_account_id,
  :environment_name,
  :id,
  :last_modified_at,
  :management_account_id,
  :requested_at,
  :role_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_at ⇒ Time

The time when the environment account connection was last modified.

Returns:

  • (Time)


2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
# File 'lib/aws-sdk-proton/types.rb', line 2290

class EnvironmentAccountConnectionSummary < Struct.new(
  :arn,
  :component_role_arn,
  :environment_account_id,
  :environment_name,
  :id,
  :last_modified_at,
  :management_account_id,
  :requested_at,
  :role_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#management_account_id ⇒ String

The ID of the management account that's connected to the environment account connection.

Returns:

  • (String)


2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
# File 'lib/aws-sdk-proton/types.rb', line 2290

class EnvironmentAccountConnectionSummary < Struct.new(
  :arn,
  :component_role_arn,
  :environment_account_id,
  :environment_name,
  :id,
  :last_modified_at,
  :management_account_id,
  :requested_at,
  :role_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#requested_at ⇒ Time

The time when the environment account connection request was made.

Returns:

  • (Time)


2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
# File 'lib/aws-sdk-proton/types.rb', line 2290

class EnvironmentAccountConnectionSummary < Struct.new(
  :arn,
  :component_role_arn,
  :environment_account_id,
  :environment_name,
  :id,
  :last_modified_at,
  :management_account_id,
  :requested_at,
  :role_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#role_arn ⇒ String

The IAM service role that's associated with the environment account connection.

Returns:

  • (String)


2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
# File 'lib/aws-sdk-proton/types.rb', line 2290

class EnvironmentAccountConnectionSummary < Struct.new(
  :arn,
  :component_role_arn,
  :environment_account_id,
  :environment_name,
  :id,
  :last_modified_at,
  :management_account_id,
  :requested_at,
  :role_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the environment account connection.

Returns:

  • (String)


2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
# File 'lib/aws-sdk-proton/types.rb', line 2290

class EnvironmentAccountConnectionSummary < Struct.new(
  :arn,
  :component_role_arn,
  :environment_account_id,
  :environment_name,
  :id,
  :last_modified_at,
  :management_account_id,
  :requested_at,
  :role_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end