Class: Aws::Proton::Types::UpdateServiceInstanceInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-proton/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:spec]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

The client token of the service instance to update.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
# File 'lib/aws-sdk-proton/types.rb', line 6331

class UpdateServiceInstanceInput < Struct.new(
  :client_token,
  :deployment_type,
  :name,
  :service_name,
  :spec,
  :template_major_version,
  :template_minor_version)
  SENSITIVE = [:spec]
  include Aws::Structure
end

#deployment_typeString

The deployment type. It defines the mode for updating a service instance, as follows:

: NONE

In this mode, a deployment *doesn't* occur. Only the requested
metadata parameters are updated.

: CURRENT_VERSION

In this mode, the service instance is deployed and updated with
the new spec that you provide. Only requested parameters are
updated. *Don’t* include major or minor version parameters when
you use this deployment type.

: MINOR_VERSION

In this mode, the service instance is deployed and updated with
the published, recommended (latest) minor version of the current
major version in use, by default. You can also specify a different
minor version of the current major version in use.

: MAJOR_VERSION

In this mode, the service instance is deployed and updated with
the published, recommended (latest) major and minor version of the
current template, by default. You can specify a different major
version that's higher than the major version in use and a minor
version.

Returns:

  • (String)


6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
# File 'lib/aws-sdk-proton/types.rb', line 6331

class UpdateServiceInstanceInput < Struct.new(
  :client_token,
  :deployment_type,
  :name,
  :service_name,
  :spec,
  :template_major_version,
  :template_minor_version)
  SENSITIVE = [:spec]
  include Aws::Structure
end

#nameString

The name of the service instance to update.

Returns:

  • (String)


6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
# File 'lib/aws-sdk-proton/types.rb', line 6331

class UpdateServiceInstanceInput < Struct.new(
  :client_token,
  :deployment_type,
  :name,
  :service_name,
  :spec,
  :template_major_version,
  :template_minor_version)
  SENSITIVE = [:spec]
  include Aws::Structure
end

#service_nameString

The name of the service that the service instance belongs to.

Returns:

  • (String)


6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
# File 'lib/aws-sdk-proton/types.rb', line 6331

class UpdateServiceInstanceInput < Struct.new(
  :client_token,
  :deployment_type,
  :name,
  :service_name,
  :spec,
  :template_major_version,
  :template_minor_version)
  SENSITIVE = [:spec]
  include Aws::Structure
end

#specString

The formatted specification that defines the service instance update.

Returns:

  • (String)


6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
# File 'lib/aws-sdk-proton/types.rb', line 6331

class UpdateServiceInstanceInput < Struct.new(
  :client_token,
  :deployment_type,
  :name,
  :service_name,
  :spec,
  :template_major_version,
  :template_minor_version)
  SENSITIVE = [:spec]
  include Aws::Structure
end

#template_major_versionString

The major version of the service template to update.

Returns:

  • (String)


6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
# File 'lib/aws-sdk-proton/types.rb', line 6331

class UpdateServiceInstanceInput < Struct.new(
  :client_token,
  :deployment_type,
  :name,
  :service_name,
  :spec,
  :template_major_version,
  :template_minor_version)
  SENSITIVE = [:spec]
  include Aws::Structure
end

#template_minor_versionString

The minor version of the service template to update.

Returns:

  • (String)


6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
# File 'lib/aws-sdk-proton/types.rb', line 6331

class UpdateServiceInstanceInput < Struct.new(
  :client_token,
  :deployment_type,
  :name,
  :service_name,
  :spec,
  :template_major_version,
  :template_minor_version)
  SENSITIVE = [:spec]
  include Aws::Structure
end