Class: Aws::Proton::Waiters::ComponentDeleted
- Inherits:
-
Object
- Object
- Aws::Proton::Waiters::ComponentDeleted
- Defined in:
- lib/aws-sdk-proton/waiters.rb,
sig/waiters.rbs
Overview
Wait until a Component is deleted. Use this after invoking DeleteComponent
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ComponentDeleted
constructor
A new instance of ComponentDeleted.
-
#wait(params = {}) ⇒ Types::GetComponentOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ComponentDeleted
Returns a new instance of ComponentDeleted.
94 95 |
# File 'lib/aws-sdk-proton/waiters.rb', line 94
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
125 126 127 |
# File 'lib/aws-sdk-proton/waiters.rb', line 125 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetComponentOutput
Returns a response object which responds to the following methods:
- #component => Types::Component
120 |
# File 'lib/aws-sdk-proton/waiters.rb', line 120
def wait: (
|