Class: Aws::Proton::Waiters::EnvironmentDeployed
- Inherits:
-
Object
- Object
- Aws::Proton::Waiters::EnvironmentDeployed
- Defined in:
- lib/aws-sdk-proton/waiters.rb,
sig/waiters.rbs
Overview
Wait until an Environment is deployed. Use this after invoking CreateEnvironment or UpdateEnvironment
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ EnvironmentDeployed
constructor
A new instance of EnvironmentDeployed.
-
#wait(params = {}) ⇒ Types::GetEnvironmentOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ EnvironmentDeployed
Returns a new instance of EnvironmentDeployed.
183 184 |
# File 'lib/aws-sdk-proton/waiters.rb', line 183
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
215 216 217 |
# File 'lib/aws-sdk-proton/waiters.rb', line 215 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetEnvironmentOutput
Returns a response object which responds to the following methods:
- #environment => Types::Environment
210 |
# File 'lib/aws-sdk-proton/waiters.rb', line 210
def wait: (
|