Class: Aws::Proton::Waiters::ServiceCreated
- Inherits:
-
Object
- Object
- Aws::Proton::Waiters::ServiceCreated
- Defined in:
- lib/aws-sdk-proton/waiters.rb,
sig/waiters.rbs
Overview
Wait until an Service has deployed its instances and possibly pipeline. Use this after invoking CreateService
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ServiceCreated
constructor
A new instance of ServiceCreated.
-
#wait(params = {}) ⇒ Types::GetServiceOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ServiceCreated
Returns a new instance of ServiceCreated.
279 280 |
# File 'lib/aws-sdk-proton/waiters.rb', line 279
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
323 324 325 |
# File 'lib/aws-sdk-proton/waiters.rb', line 323 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetServiceOutput
Returns a response object which responds to the following methods:
- #service => Types::Service
318 |
# File 'lib/aws-sdk-proton/waiters.rb', line 318
def wait: (
|