Class: Aws::Proton::Waiters::ServiceInstanceDeployed

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-proton/waiters.rb,
sig/waiters.rbs

Overview

Wait until a ServiceInstance is deployed. Use this after invoking CreateService or UpdateServiceInstance

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ ServiceInstanceDeployed

Returns a new instance of ServiceInstanceDeployed.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 999
  • :delay (Integer) — default: 5
  • :before_attempt (Proc)
  • :before_wait (Proc)


380
381
# File 'lib/aws-sdk-proton/waiters.rb', line 380

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



412
413
414
# File 'lib/aws-sdk-proton/waiters.rb', line 412

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetServiceInstanceOutput

Returns a response object which responds to the following methods:

Options Hash (params):

  • :name (required, String)

    The name of a service instance that you want to get the detailed data for.

  • :service_name (required, String)

    The name of the service that you want the service instance input for.

Returns:



407
# File 'lib/aws-sdk-proton/waiters.rb', line 407

def wait: (