Class: Aws::Proton::Waiters::ServicePipelineDeployed

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-proton/waiters.rb,
sig/waiters.rbs

Overview

Wait until an ServicePipeline is deployed. Use this after invoking CreateService or UpdateServicePipeline

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ ServicePipelineDeployed

Returns a new instance of ServicePipelineDeployed.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 360
  • :delay (Integer) — default: 10
  • :before_attempt (Proc)
  • :before_wait (Proc)


425
426
# File 'lib/aws-sdk-proton/waiters.rb', line 425

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



457
458
459
# File 'lib/aws-sdk-proton/waiters.rb', line 457

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetServiceOutput

Returns a response object which responds to the following methods:

Options Hash (params):

  • :name (required, String)

    The name of the service that you want to get the detailed data for.

Returns:



452
# File 'lib/aws-sdk-proton/waiters.rb', line 452

def wait: (