Class: Aws::Proton::Waiters::ServiceUpdated

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-proton/waiters.rb,
sig/waiters.rbs

Overview

Wait until a Service, its instances, and possibly pipeline have been deployed after UpdateService is invoked

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ ServiceUpdated

Returns a new instance of ServiceUpdated.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 999
  • :delay (Integer) — default: 5
  • :before_attempt (Proc)
  • :before_wait (Proc)


521
522
# File 'lib/aws-sdk-proton/waiters.rb', line 521

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



571
572
573
# File 'lib/aws-sdk-proton/waiters.rb', line 571

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetServiceOutput

Returns a response object which responds to the following methods:

Options Hash (params):

  • :name (required, String)

    The name of the service that you want to get the detailed data for.

Returns:



566
# File 'lib/aws-sdk-proton/waiters.rb', line 566

def wait: (