Class: Aws::Proton::Waiters::ServiceInstanceDeployed
- Inherits:
-
Object
- Object
- Aws::Proton::Waiters::ServiceInstanceDeployed
- Defined in:
- lib/aws-sdk-proton/waiters.rb,
sig/waiters.rbs
Overview
Wait until a ServiceInstance is deployed. Use this after invoking CreateService or UpdateServiceInstance
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ServiceInstanceDeployed
constructor
A new instance of ServiceInstanceDeployed.
-
#wait(params = {}) ⇒ Types::GetServiceInstanceOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ServiceInstanceDeployed
Returns a new instance of ServiceInstanceDeployed.
380 381 |
# File 'lib/aws-sdk-proton/waiters.rb', line 380
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
412 413 414 |
# File 'lib/aws-sdk-proton/waiters.rb', line 412 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetServiceInstanceOutput
Returns a response object which responds to the following methods:
- #service_instance => Types::ServiceInstance
407 |
# File 'lib/aws-sdk-proton/waiters.rb', line 407
def wait: (
|