Class: Aws::Proton::Waiters::ServiceUpdated
- Inherits:
-
Object
- Object
- Aws::Proton::Waiters::ServiceUpdated
- Defined in:
- lib/aws-sdk-proton/waiters.rb,
sig/waiters.rbs
Overview
Wait until a Service, its instances, and possibly pipeline have been deployed after UpdateService is invoked
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ServiceUpdated
constructor
A new instance of ServiceUpdated.
-
#wait(params = {}) ⇒ Types::GetServiceOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ServiceUpdated
Returns a new instance of ServiceUpdated.
521 522 |
# File 'lib/aws-sdk-proton/waiters.rb', line 521
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
571 572 573 |
# File 'lib/aws-sdk-proton/waiters.rb', line 571 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetServiceOutput
Returns a response object which responds to the following methods:
- #service => Types::Service
566 |
# File 'lib/aws-sdk-proton/waiters.rb', line 566
def wait: (
|